@@ -21,6 +21,7 @@
 #include <ags/X/ags_line_editor_callbacks.h>
 
 #include <ags/libags.h>
+#include <ags/libags-audio.h>
 
 #include <ags/i18n.h>
 
@@ -36,8 +37,10 @@ void ags_line_editor_get_property(GObject *gobject,
 				  guint prop_id,
 				  GValue *value,
 				  GParamSpec *param_spec);
+
 void ags_line_editor_connect(AgsConnectable *connectable);
 void ags_line_editor_disconnect(AgsConnectable *connectable);
+
 void ags_line_editor_set_update(AgsApplicable *applicable, gboolean update);
 void ags_line_editor_apply(AgsApplicable *applicable);
 void ags_line_editor_reset(AgsApplicable *applicable);
@@ -64,7 +67,7 @@ ags_line_editor_get_type(void)
   static volatile gsize g_define_type_id__volatile = 0;
 
   if(g_once_init_enter (&g_define_type_id__volatile)){
-    GType ags_type_line_editor;
+    GType ags_type_line_editor = 0;
 
     static const GTypeInfo ags_line_editor_info = {
       sizeof (AgsLineEditorClass),
@@ -102,7 +105,7 @@ ags_line_editor_get_type(void)
 				AGS_TYPE_APPLICABLE,
 				&ags_applicable_interface_info);
 
-    g_once_init_leave (&g_define_type_id__volatile, ags_type_line_editor);
+    g_once_init_leave(&g_define_type_id__volatile, ags_type_line_editor);
   }
 
   return g_define_type_id__volatile;
@@ -124,7 +127,7 @@ ags_line_editor_class_init(AgsLineEditorClass *line_editor)
    *
    * The assigned #AgsChannel to edit.
    * 
-   * Since: 1.0.0
+   * Since: 2.0.0
    */
   param_spec = g_param_spec_object("channel",
 				   i18n_pspec("assigned channel"),
@@ -237,6 +240,10 @@ ags_line_editor_connect(AgsConnectable *connectable)
     ags_connectable_connect(AGS_CONNECTABLE(line_editor->output_editor));
   }
   
+  if(line_editor->input_editor != NULL){
+    ags_connectable_connect(AGS_CONNECTABLE(line_editor->input_editor));
+  }
+
   if(line_editor->member_editor != NULL){
     ags_connectable_connect(AGS_CONNECTABLE(line_editor->member_editor));
   }
@@ -269,6 +276,10 @@ ags_line_editor_disconnect(AgsConnectable *connectable)
     ags_connectable_connect(AGS_CONNECTABLE(line_editor->output_editor));
   }
   
+  if(line_editor->input_editor != NULL){
+    ags_connectable_connect(AGS_CONNECTABLE(line_editor->input_editor));
+  }
+
   if(line_editor->member_editor != NULL){
     ags_connectable_disconnect(AGS_CONNECTABLE(line_editor->member_editor));
   }
@@ -300,6 +311,10 @@ ags_line_editor_apply(AgsApplicable *applicable)
   if(line_editor->output_editor != NULL){
     ags_applicable_apply(AGS_APPLICABLE(line_editor->output_editor));
   }
+
+  if(line_editor->input_editor != NULL){
+    ags_applicable_apply(AGS_APPLICABLE(line_editor->input_editor));
+  }
 }
 
 void
@@ -317,6 +332,10 @@ ags_line_editor_reset(AgsApplicable *applicable)
     ags_applicable_reset(AGS_APPLICABLE(line_editor->output_editor));
   }
 
+  if(line_editor->input_editor != NULL){
+    ags_applicable_reset(AGS_APPLICABLE(line_editor->input_editor));
+  }
+
   if(line_editor->member_editor != NULL){
     ags_applicable_reset(AGS_APPLICABLE(line_editor->member_editor));
   }
@@ -329,7 +348,7 @@ ags_line_editor_reset(AgsApplicable *applicable)
  *
  * Is called as channel gets modified.
  *
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 void
 ags_line_editor_set_channel(AgsLineEditor *line_editor,
@@ -339,6 +358,7 @@ ags_line_editor_set_channel(AgsLineEditor *line_editor,
     line_editor->link_editor = NULL;
     gtk_widget_destroy(GTK_WIDGET(line_editor->link_editor));
     gtk_widget_destroy(GTK_WIDGET(line_editor->output_editor));
+    gtk_widget_destroy(GTK_WIDGET(line_editor->input_editor));
     gtk_widget_destroy(GTK_WIDGET(line_editor->member_editor));
   }
 
@@ -357,7 +377,7 @@ ags_line_editor_set_channel(AgsLineEditor *line_editor,
 			   0);
       }
 
-      /* recall */
+      /* output */
       if(line_editor->editor_type[i] == AGS_TYPE_OUTPUT_EDITOR){
 	line_editor->output_editor = ags_output_editor_new();
 	gtk_box_pack_start(GTK_BOX(line_editor),
@@ -366,6 +386,15 @@ ags_line_editor_set_channel(AgsLineEditor *line_editor,
 			   0);
       }
       
+      /* input */
+      if(line_editor->editor_type[i] == AGS_TYPE_INPUT_EDITOR){
+	line_editor->input_editor = ags_input_editor_new();
+	gtk_box_pack_start(GTK_BOX(line_editor),
+			   GTK_WIDGET(line_editor->input_editor),
+			   FALSE, FALSE,
+			   0);
+      }
+
       /* recall */
       if(line_editor->editor_type[i] == AGS_TYPE_LINE_MEMBER_EDITOR){
 	line_editor->member_editor = ags_line_member_editor_new();
@@ -382,11 +411,11 @@ ags_line_editor_set_channel(AgsLineEditor *line_editor,
  * ags_line_editor_new:
  * @channel: the channel to edit
  *
- * Creates an #AgsLineEditor
+ * Create a new instance of #AgsLineEditor
  *
- * Returns: a new #AgsLineEditor
+ * Returns: the new #AgsLineEditor
  *
- * Since: 1.0.0
+ * Since: 2.0.0
  */
 AgsLineEditor*
 ags_line_editor_new(AgsChannel *channel)
